#!/bin/bash

# Import the default values...
# Make sure they are from the correct directory
sourcedir="$( cd "$( dirname "$0" )" && pwd )"
source $sourcedir/bzrdefaults
# Make sure the bzrdefaults file actually exists...
if [ ! -f $sourcedir/bzrdefaults ]; then
	zenity --error --text="You have not got a $sourcedir/bzrdefaults file" --ellipsize
	exit 100
fi
# Make sure we are not a controlled (top-level) directory
if [ -d "$1"/.bzr ]; then
	zenity --error --text="This directory ($1) is ALREADY a bzr-controlled project" --ellipsize
else
	# We need to ask for a new project number - but we'll suggest the current directory's name
	pathend="$(basename "$1")"
	# For the DISTANT URL, we need to replace spaces. It's easier like this.
	pathend="${pathend// /_}"
	project="$(zenity --entry --title=$defaultrepo --text='Project name: use only letters, numbers and underscores' --entry-text="$pathend")"
	if [ "$?" = 0 ]; then
		# For the DISTANT URL, we need to replace spaces. It's easier like this.
		urlproject="${project// /_}"	
		user="$(zenity --entry --title=$defaultrepo --text='Username' --entry-text=$(whoami))"
		if [ "$?" = 0 ]; then
			pass="$(zenity --password --title=$user@$defaultrepo --text='Password for project server')"
			if [ "$?" = 0 ]; then
                # Bracket this lot to get a progress indicator. echo 100 (percent) closes the progress window.
				{
				# See if the project already exists...
				echo "# Seeing if $defaultrepodirbase/$urlproject already exists..."
				sshpass -p "$pass" ssh -C $user@$defaultrepo -p $defaultport -o StrictHostKeyChecking=no "[ -d $defaultrepodirbase/$urlproject ]" 
				if [ "$?" = 0 ]; then
					zenity --error --text="$defaultrepodirbase/$urlproject already exists!" --ellipsize
					echo 100
				else
					# Create the distant repo...
					echo "# Creating the repository..."
					sshpass -p "$pass" bzr init-repo --no-trees bzr+ssh://"$user"@"$defaultrepo":"$defaultport""$defaultrepodirbase"/"$urlproject"
					if [ "$?" = 0 ]; then
						# create the rest...
						echo 33
						echo "# Creating the workspace..."
						sshpass -p "$pass" bzr init --no-tree bzr+ssh://"$user"@"$defaultrepo":"$defaultport""$defaultrepodirbase"/"$urlproject"
					
						# and now check it out locally...
						if [ "$?" = 0 ]; then
							echo 66
							echo "# Checking out the repository..."
                            # The bleow can be useful for debugging...
							#echo "$user"@"$defaultrepo":"$defaultport""$defaultrepodirbase"/"$urlproject"/  "$1" | zenity --text-info
							#echo $1 | zenity --text-info
							sshpass -p "$pass" bzr checkout bzr+ssh://"$user"@"$defaultrepo":"$defaultport""$defaultrepodirbase"/"$urlproject"  "$1"
							if [ "$?" != 0 ]; then
								zenity --error --text="There was an ssh error checking out the repository" --ellipsize
								echo 100					
							fi
						else
							zenity --error --text="There was an ssh error creating the workspace" --ellipsize
							echo 100
						fi
					else
						zenity --error --text="There was an ssh error creating the repository" --ellipsize
						echo 100			
					fi
				fi
				} | zenity --progress  --text="Setting up..."  --no-cancel --auto-close
			fi
			
		fi
	fi
fi


